import { isArray, isFunction } from '../vendors/toolbox';
import { isEnumField } from './is';
const cachedEnumOptionMap = new Map();
function cacheDynamicEnumOptions(moduleName, field, options) {
    if (!isEnumField(field)) {
        return;
    }
    if (!cachedEnumOptionMap.has(moduleName)) {
        cachedEnumOptionMap.set(moduleName, new Map());
    }
    const moduleSpecificCache = cachedEnumOptionMap.get(moduleName);
    if (moduleSpecificCache.has(field.name) ||
        !isFunction(field.options)) {
        return;
    }
    if (isArray(options)) {
        moduleSpecificCache.set(field.name, options);
        cachedEnumOptionMap.set(moduleName, moduleSpecificCache);
    }
    else {
        field.options().then(({ success, data }) => {
            if (success) {
                moduleSpecificCache.set(field.name, data);
                cachedEnumOptionMap.set(moduleName, moduleSpecificCache);
            }
        });
    }
}
function getCachedEnumOptions(moduleName, field) {
    return isEnumField(field) && cachedEnumOptionMap.has(moduleName)
        ? cachedEnumOptionMap.get(moduleName).get(field.name)
        : undefined;
}
export { cacheDynamicEnumOptions, getCachedEnumOptions };
