import { __awaiter } from "tslib";
import { isString, isFunction, noop } from '@ntks/toolbox';
import { convertAsyncFunctionMapToServerActionMap, ensureModuleExists, getDependencies, getComponents, } from '../module';
const moduleContextMap = new Map();
function isResultLogicallySuccessful(result) {
    return result.success === true;
}
function createServerActionExecutor(actions, resultAsserter = isResultLogicallySuccessful) {
    return function (actionName, params, success, fail) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!(actionName in actions)) {
                return { success: false, message: `不存在 \`${actionName}\` 这个请求资源` };
            }
            let resolvedParams;
            let resolvedSuccessCallback;
            let resolvedFailCallback;
            if (params && isFunction(params)) {
                resolvedParams = undefined;
                resolvedSuccessCallback = (params || noop);
                resolvedFailCallback = (success || noop);
            }
            else {
                resolvedParams = params;
                resolvedSuccessCallback = (success || noop);
                resolvedFailCallback = fail || noop;
            }
            const result = yield actions[actionName].execute(resolvedParams);
            if (resultAsserter(result, actionName)) {
                resolvedSuccessCallback(result.data, result.extra, result);
            }
            else {
                resolvedFailCallback(result.message, result);
            }
            return result;
        });
    };
}
function constructModuleContextDescriptor(moduleName) {
    const module = ensureModuleExists(moduleName);
    const descriptor = { moduleName, actions: module.actions };
    if (module.model) {
        descriptor.model = module.model;
    }
    return descriptor;
}
function createModuleContext(descriptor) {
    const { moduleName, model, actions } = isString(descriptor)
        ? constructModuleContextDescriptor(descriptor)
        : descriptor;
    if (moduleContextMap.has(moduleName)) {
        return moduleContextMap.get(moduleName);
    }
    const ctx = {
        getModuleName: () => moduleName,
        getModel: () => model,
        getDependencies: getDependencies.bind(null, moduleName),
        getComponents: getComponents.bind(null, moduleName),
        execute: createServerActionExecutor(convertAsyncFunctionMapToServerActionMap(actions)),
    };
    moduleContextMap.set(moduleName, ctx);
    return ctx;
}
export { createModuleContext };
