import { __awaiter } from "tslib";
import { getAppHelper } from '../../vendors/organik';
import { isString } from '../../utils';
import { BaseHeadlessWidget } from '../base';
class ActionHeadlessWidget extends BaseHeadlessWidget {
    getAction() {
        return this.getProp('action');
    }
    getConfig() {
        return this.getAction().config || {};
    }
    /**
     * Execute client action with view context
     *
     * @param viewContext injected view context
     */
    execute(viewContext) {
        const appHelper = getAppHelper();
        const { danger, confirm, text, execute } = this.getAction();
        let beforeExecute;
        let needConfirm;
        if (danger) {
            needConfirm = confirm !== false;
        }
        else {
            needConfirm = !!confirm;
        }
        if (needConfirm) {
            beforeExecute = callback => appHelper.confirm(isString(confirm) ? confirm : `确定要${text || '执行此操作'}？`, {
                title: '提示',
                type: 'warning',
                affirmButton: callback,
            });
        }
        const executeAction = () => __awaiter(this, void 0, void 0, function* () {
            if (execute) {
                yield Promise.resolve(execute(viewContext, appHelper));
            }
        });
        if (beforeExecute) {
            beforeExecute(executeAction);
        }
        else {
            executeAction();
        }
    }
    /**
     * Render content of action widget
     *
     * @param iconWithTextRenderer render `Icon` component and text
     * @returns content of action widget
     */
    renderContent(iconWithTextRenderer) {
        const text = this.getAction().text || '';
        let { showIcon, iconOnly, icon } = this.getConfig();
        if (showIcon === undefined) {
            showIcon = this.getCommonBehavior('action.showIcon');
        }
        if (iconOnly === undefined) {
            iconOnly = this.getCommonBehavior('action.iconOnly');
        }
        return !showIcon || !icon ? text : iconWithTextRenderer(icon, text, iconOnly);
    }
}
export { ActionHeadlessWidget };
