import { isFunction, createMoment } from '../../utils';
import { FieldHeadlessWidget } from './Field';
class DateFieldHeadlessWidget extends FieldHeadlessWidget {
    getRangeValue() {
        const context = this.getViewContext();
        const { fromField, toField } = this.getConfig();
        if (!fromField && !toField) {
            return context.getFieldValue(this.getField().name);
        }
        const range = ['', ''];
        if (fromField) {
            range[0] = context.getFieldValue(fromField) || '';
        }
        if (toField) {
            range[1] = context.getFieldValue(toField) || '';
        }
        return range;
    }
    getRangePlaceholders() {
        const { fromField, fromPlaceholder, toField, toPlaceholder } = this.getConfig();
        const labels = ['开始日期', '结束日期'];
        const placeholders = [];
        const fields = this.getViewContext().getFields();
        [
            { name: fromField, placeholder: fromPlaceholder },
            { name: toField, placeholder: toPlaceholder },
        ].forEach((targetField, idx) => {
            const { name, placeholder } = targetField;
            const field = name ? fields.find(f => name === f.name) : undefined;
            placeholders[idx] = placeholder || `请选择${(field && field.label) || labels[idx]}`;
        });
        return placeholders;
    }
    formatDate(value) {
        if (isFunction(this.getField().formatter)) {
            return this.getField().formatter(value, this.getViewContext().getValue());
        }
        return this.getConfig().format ? createMoment(value).format(this.getConfig().format) : value;
    }
}
export { DateFieldHeadlessWidget };
