import { createMoment } from '../../utils';
import { FilterHeadlessWidget } from './Filter';
class DateFilterHeadlessWidget extends FilterHeadlessWidget {
    getRangeValue() {
        const context = this.getSearchContext();
        const { fromField, toField } = this.getConfig();
        if (!fromField && !toField) {
            return context.getFilterValue(this.getFilter().name);
        }
        const range = ['', ''];
        if (fromField) {
            range[0] = context.getFilterValue(fromField) || '';
        }
        if (toField) {
            range[1] = context.getFilterValue(toField) || '';
        }
        return range;
    }
    getRangePlaceholders() {
        const { fromField, fromPlaceholder, toField, toPlaceholder } = this.getConfig();
        const labels = ['开始日期', '结束日期'];
        const placeholders = [];
        const filters = this.getSearchContext().getFilters();
        [
            { name: fromField, placeholder: fromPlaceholder },
            { name: toField, placeholder: toPlaceholder },
        ].forEach((targetField, idx) => {
            const { name, placeholder } = targetField;
            const filter = name ? filters.find(f => name === f.name) : undefined;
            placeholders[idx] = placeholder || `请选择${(filter && filter.label) || labels[idx]}`;
        });
        return placeholders;
    }
    formatDate(value) {
        return this.getConfig().format ? createMoment(value).format(this.getConfig().format) : value;
    }
}
export { DateFilterHeadlessWidget };
